@@ -1,3 +1,4 @@
+#include <QtGui>
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
@@ -23,8 +24,10 @@ mainwindow::mainwindow(QWidget *parent) :
     if (!QFile::exists("/opt/cssutransitionstuner/tactileinstalled")) {
         ui->tactile->setDisabled(true);
     }
-
+    connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
+    orientationChanged();
     readvalues();
+    abouttext = "CSSU Transitions Tuner ver. 0.0.5<br /><br />Auhtor: d-iivil<br />Licence: GPL";
 }
 
 mainwindow::~mainwindow()
@@ -32,6 +35,24 @@ mainwindow::~mainwindow()
     delete ui;
 }
 
+void mainwindow::orientationChanged()
+{
+     QRect screenGeometry = QApplication::desktop()->screenGeometry();
+     if (screenGeometry.width() > screenGeometry.height())
+     {
+         ui->widget_bot->setVisible(false);
+         ui->widget_right->setVisible(true);
+
+         //ui->listWidget->setMaximumWidth(720);
+     }
+     else
+     {
+         ui->widget_bot->setVisible(true);
+         ui->widget_right->setVisible(false);
+     }
+
+}
+
 void mainwindow::readvalues()
 {
     QString path;
@@ -423,3 +444,27 @@ void mainwindow::on_pushButton_2_clicked()
     msgBox.setText("CSSU Transitions Tuner ver. 0.0.4<br /><br />Auhtor: d-iivil<br />Licence: GPL");
     msgBox.exec();
 }
+
+void mainwindow::on_pushButton_3_clicked()
+{
+    ui->pushButton->setDisabled(true);
+    // sleep(1);
+    storevalues();
+    // QMaemo5InformationBox::information(this, tr("Settings saved."), QMaemo5InformationBox::DefaultTimeout);
+    //QMaemo5InformationBox::information(this, tr("Transitions updated!") +  "<br /><br />" + tr("Some changes requires restarting the device to activate them."), QMaemo5InformationBox::NoTimeout);
+
+    QMessageBox msgBox;
+    msgBox.setWindowTitle("CSSU Transitions Tuner");
+    msgBox.setText(abouttext);
+    msgBox.exec();
+
+    ui->pushButton->setEnabled(true);
+}
+
+void mainwindow::on_pushButton_5_clicked()
+{
+    QMessageBox msgBox;
+    msgBox.setWindowTitle("CSSU Transitions Tuner");
+    msgBox.setText(abouttext);
+    msgBox.exec();
+}
